 keys->insertItem(i18n("Switch to desktop 1"),  "Switch to desktop 1"   ,"CTRL+F1");
 keys->insertItem(i18n("Switch to desktop 2"),  "Switch to desktop 2"   ,"CTRL+F2");
 keys->insertItem(i18n("Switch to desktop 3"),  "Switch to desktop 3"   ,"CTRL+F3");
 keys->insertItem(i18n("Switch to desktop 4"),  "Switch to desktop 4"   ,"CTRL+F4");
 keys->insertItem(i18n("Switch to desktop 5"),  "Switch to desktop 5"   ,"CTRL+F5");
 keys->insertItem(i18n("Switch to desktop 6"),  "Switch to desktop 6"   ,"CTRL+F6");
 keys->insertItem(i18n("Switch to desktop 7"),  "Switch to desktop 7"   ,"CTRL+F7");
 keys->insertItem(i18n("Switch to desktop 8"),  "Switch to desktop 8"   ,"CTRL+F8");


 keys->insertItem(i18n("Window operations menu"),  "Pop-up window operations menu"   ,"ALT+F3");
 keys->insertItem(i18n("Window close"),"Window close", "ALT+F4");
 keys->insertItem(i18n("Window maximize"),"Window maximize", "");
 keys->insertItem(i18n("Window maximize vertical"),"Window maximize vertical", "");
 keys->insertItem(i18n("Window maximize horizontal"),"Window maximize horizontal", "");
 keys->insertItem(i18n("Window iconify"),"Window iconify", "");
 keys->insertItem(i18n("Window shade"),"Window shade", "");
 keys->insertItem(i18n("Window move"),"Window move", "");
 keys->insertItem(i18n("Window resize"),"Window resize", "");

 keys->insertItem(i18n("Mouse emulation"),"Mouse emulation", "F12");

 keys->insertItem(i18n("Logout"),"Logout", "CTRL+ALT+Delete");

 keys->insertItem(i18n("Kill Window"),"Kill Window", "CTRL+ALT+Escape");
